package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgSrvOrganType;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndSrvOrganLevel;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganListVo;
import com.hungraim.ltc.service.SrvOrganService;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping("/api.apply/srvOrgan")
@AllArgsConstructor
public class SrvOrganController {

    private final SrvOrganService srvOrganService;

    /**
     * 分页查询护理机构列表
     *
     * @param pageNum        分页参数
     * @param pageSize       分页参数
     * @param organId        适用机构id
     * @param isInvolveChild 是否包含下层机构
     * @param creditCode     统一社会信用代码
     * @param srvOrganName   护理机构名称
     * @return 返回护理机构列表
     */
    @GetMapping("/list")
    public Result<Page<SrvOrganListVo>> getSrvOrganList(Integer pageNum, Integer pageSize, Long organId, Boolean isInvolveChild, String creditCode, String srvOrganName) {
        Page<SrvOrganListVo> page = new Page<>(pageNum, pageSize);
        page = srvOrganService.getSrvOrganList(page, organId, isInvolveChild, creditCode, srvOrganName);
        return Result.success(page);
    }

    /**
     * 获取所有服务机构等级
     *
     * @return 返回服务机构等级
     */
    @GetMapping("/srvOrganLevels")
    public Result<List<ChFndSrvOrganLevel>> getSrvOrganLevels() {
        List<ChFndSrvOrganLevel> srvOrganLevels = srvOrganService.getSrvOrganLevels();
        return Result.success(srvOrganLevels);
    }

    /**
     * 获取所有服务机构类型
     *
     * @return 返回所有服务机构类型
     */
    @GetMapping("/srvOrganTypes")
    public Result<List<ChCfgSrvOrganType>> getSrvOrganTypes() {
        List<ChCfgSrvOrganType> chCfgSrvOrganTypes = srvOrganService.getSrvOrganTypes();
        return Result.success(chCfgSrvOrganTypes);
    }


}
