package com.hungraim.ltc.governance.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.governance.service.SuperviseOrganEmpService;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrgan;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganEmpVO;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 监管机构人员信息管理Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/supervise")
@Slf4j
public class SuperviseOrganEmpController {

    @Autowired
    private SuperviseOrganEmpService superviseOrganEmpService;

    /**
     * 监管机构人员信息列表
     *
     * @param pageNum       页码
     * @param pageSize      每页展示条数
     * @param organIds      适用机构id
     * @param organName     监管机构名称
     * @param superviseType 监管人员类型 监管人员：0；管理人员：1
     * @param superviseName 监管人员姓名
     * @param superviseTel  监管人员手机号
     * @param status        状态 有效：0；失效：1
     */
    @RequestMapping("/superviseOrganEmpList")
    public Result<Page<SuperviseOrganEmpVO>> superviseOrganEmpList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                                   String organIds, String organName, String superviseType, String superviseName, String superviseTel, String status) {
        Page<SuperviseOrganEmpVO> page = new Page<>(pageNum, pageSize);
        page = superviseOrganEmpService.superviseOrganEmpList(page, organIds, organName, superviseType, superviseName, superviseTel, status);
        return Result.success(page);
    }

    /**
     * 更改监管机构人员状态
     *
     * @param empId  监管机构人员id
     * @param isLock 状态 有效：0；失效：1
     */
    @DeleteMapping("/updateEmpStatus")
    public Result updateEmpStatus(String empId, Short isLock) {
        if (StringUtils.isBlank(empId) || isLock == null || (isLock != 1 && isLock != 0)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        superviseOrganEmpService.updateEmpStatus(empId, isLock);
        return Result.success();
    }

    /**
     * 新增或编辑监管机构人员
     *
     * @param empId        监管机构人员id 有就修改,没有就新增
     * @param spvOrganId   监管机构id
     * @param spvEmpName   监管人员姓名
     * @param certifType   证件类型
     * @param certifNum    证件号码
     * @param gender       性别 男：M；女：F；不确定N
     * @param age          年龄
     * @param superviseTel 手机号码
     * @param status       人员类型 有效：0；失效：1
     */
    @DeleteMapping("/insertOrUpdateEmpInfo")
    public Result insertOrUpdateEmpInfo(Long empId, Long spvOrganId, String spvEmpName, String certifType,
                                        String certifNum, String gender, Short age, String superviseTel, Short status) {
        //参数校验
        if (empId == null && spvOrganId == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (StringUtils.isBlank(spvEmpName) || StringUtils.isBlank(certifType) || StringUtils.isBlank(gender) || StringUtils.isBlank(superviseTel) || (status != 1 && status != 0)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        superviseOrganEmpService.insertOrUpdateEmpInfo(empId, spvOrganId, spvEmpName, certifType, certifNum, gender, age, superviseTel, status);
        return Result.success();
    }

    /**
     * 查询监管机构信息
     *
     * @param organId 适用机构id
     */
    @RequestMapping("/superviseOrganEmpList")
    public Result<List<ChSuperviseOrgan>> superviseOrganList(Long organId) {
        List<ChSuperviseOrgan> result = superviseOrganEmpService.superviseOrganList(organId);
        return Result.success(result);
    }
}
